client

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2026 License: AGPL-3.0 Imports: 14 Imported by: 0

Documentation

Overview

Package client provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.6.0 DO NOT EDIT.

Index

Constants

const (
	BearerAuthScopes = "BearerAuth.Scopes"
	TokenAuthScopes  = "TokenAuth.Scopes"
)

Variables

This section is empty.

Functions

func GetSwagger

func GetSwagger() (swagger *openapi3.T, err error)

GetSwagger returns the Swagger specification corresponding to the generated code in this file. The external references of Swagger specification are resolved. The logic of resolving external references is tightly connected to "import-mapping" feature. Externally referenced files must be embedded in the corresponding golang packages. Urls can be supported but this task was out of the scope.

func NewCreateEventRequest

func NewCreateEventRequest(server string, params *CreateEventParams, body CreateEventJSONRequestBody) (*http.Request, error)

NewCreateEventRequest calls the generic CreateEvent builder with application/json body

func NewCreateEventRequestWithBody

func NewCreateEventRequestWithBody(server string, params *CreateEventParams, contentType string, body io.Reader) (*http.Request, error)

NewCreateEventRequestWithBody generates requests for CreateEvent with any type of body

func NewCreateEventTypeRequest

func NewCreateEventTypeRequest(server string, body CreateEventTypeJSONRequestBody) (*http.Request, error)

NewCreateEventTypeRequest calls the generic CreateEventType builder with application/json body

func NewCreateEventTypeRequestWithBody

func NewCreateEventTypeRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewCreateEventTypeRequestWithBody generates requests for CreateEventType with any type of body

func NewCreateEventTypeVersionRequest

func NewCreateEventTypeVersionRequest(server string, eventTypeAction EventTypeAction, body CreateEventTypeVersionJSONRequestBody) (*http.Request, error)

NewCreateEventTypeVersionRequest calls the generic CreateEventTypeVersion builder with application/json body

func NewCreateEventTypeVersionRequestWithBody

func NewCreateEventTypeVersionRequestWithBody(server string, eventTypeAction EventTypeAction, contentType string, body io.Reader) (*http.Request, error)

NewCreateEventTypeVersionRequestWithBody generates requests for CreateEventTypeVersion with any type of body

func NewCreateSourceRequest

func NewCreateSourceRequest(server string, body CreateSourceJSONRequestBody) (*http.Request, error)

NewCreateSourceRequest calls the generic CreateSource builder with application/json body

func NewCreateSourceRequestWithBody

func NewCreateSourceRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewCreateSourceRequestWithBody generates requests for CreateSource with any type of body

func NewCreateTokenRequest

func NewCreateTokenRequest(server string, sourceId SourceId, body CreateTokenJSONRequestBody) (*http.Request, error)

NewCreateTokenRequest calls the generic CreateToken builder with application/json body

func NewCreateTokenRequestWithBody

func NewCreateTokenRequestWithBody(server string, sourceId SourceId, contentType string, body io.Reader) (*http.Request, error)

NewCreateTokenRequestWithBody generates requests for CreateToken with any type of body

func NewDeleteEventTypeRequest

func NewDeleteEventTypeRequest(server string, eventTypeAction EventTypeAction) (*http.Request, error)

NewDeleteEventTypeRequest generates requests for DeleteEventType

func NewDeleteTokenRequest

func NewDeleteTokenRequest(server string, sourceId SourceId, tokenId TokenId) (*http.Request, error)

NewDeleteTokenRequest generates requests for DeleteToken

func NewGetEventByIDRequest

func NewGetEventByIDRequest(server string, eventId EventId) (*http.Request, error)

NewGetEventByIDRequest generates requests for GetEventByID

func NewGetEventTypeByIDRequest

func NewGetEventTypeByIDRequest(server string, eventTypeAction EventTypeAction) (*http.Request, error)

NewGetEventTypeByIDRequest generates requests for GetEventTypeByID

func NewGetEventTypesRequest

func NewGetEventTypesRequest(server string, params *GetEventTypesParams) (*http.Request, error)

NewGetEventTypesRequest generates requests for GetEventTypes

func NewGetEventsRequest

func NewGetEventsRequest(server string, params *GetEventsParams) (*http.Request, error)

NewGetEventsRequest generates requests for GetEvents

func NewGetSourceByIDRequest

func NewGetSourceByIDRequest(server string, sourceId SourceId) (*http.Request, error)

NewGetSourceByIDRequest generates requests for GetSourceByID

func NewGetSourcesRequest

func NewGetSourcesRequest(server string, params *GetSourcesParams) (*http.Request, error)

NewGetSourcesRequest generates requests for GetSources

func NewGetTokensRequest

func NewGetTokensRequest(server string, sourceId SourceId) (*http.Request, error)

NewGetTokensRequest generates requests for GetTokens

func NewGetUserProfileRequest

func NewGetUserProfileRequest(server string) (*http.Request, error)

NewGetUserProfileRequest generates requests for GetUserProfile

func NewLogInRequest

func NewLogInRequest(server string, body LogInJSONRequestBody) (*http.Request, error)

NewLogInRequest calls the generic LogIn builder with application/json body

func NewLogInRequestWithBody

func NewLogInRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewLogInRequestWithBody generates requests for LogIn with any type of body

func NewRollbackEventTypeVersionRequest

func NewRollbackEventTypeVersionRequest(server string, eventTypeAction EventTypeAction) (*http.Request, error)

NewRollbackEventTypeVersionRequest generates requests for RollbackEventTypeVersion

func PathToRawSpec

func PathToRawSpec(pathToFile string) map[string]func() ([]byte, error)

Constructs a synthetic filesystem for resolving external references when loading openapi specifications.

Types

type ActionFilter

type ActionFilter = string

ActionFilter defines model for action_filter.

type Actor

type Actor struct {
	ActorType string                  `json:"actor_type"`
	Id        string                  `json:"id"`
	Metadata  *map[string]interface{} `json:"metadata,omitempty"`
	Name      *string                 `json:"name,omitempty"`
}

Actor defines model for Actor.

type BadRequestError

type BadRequestError = ErrorSchema

BadRequestError defines model for BadRequestError.

type Client

type Client struct {
	// The endpoint of the server conforming to this interface, with scheme,
	// https://api.deepmap.com for example. This can contain a path relative
	// to the server, such as https://api.deepmap.com/dev-test, and all the
	// paths in the swagger spec will be appended to the server.
	Server string

	// Doer for performing requests, typically a *http.Client with any
	// customized settings, such as certificate chains.
	Client HttpRequestDoer

	// A list of callbacks for modifying requests which are generated before sending over
	// the network.
	RequestEditors []RequestEditorFn
}

Client which conforms to the OpenAPI3 specification for this service.

func NewClient

func NewClient(server string, opts ...ClientOption) (*Client, error)

Creates a new Client, with reasonable defaults

func (*Client) CreateEvent

func (c *Client) CreateEvent(ctx context.Context, params *CreateEventParams, body CreateEventJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateEventType

func (c *Client) CreateEventType(ctx context.Context, body CreateEventTypeJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateEventTypeVersion

func (c *Client) CreateEventTypeVersion(ctx context.Context, eventTypeAction EventTypeAction, body CreateEventTypeVersionJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateEventTypeVersionWithBody

func (c *Client) CreateEventTypeVersionWithBody(ctx context.Context, eventTypeAction EventTypeAction, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateEventTypeWithBody

func (c *Client) CreateEventTypeWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateEventWithBody

func (c *Client) CreateEventWithBody(ctx context.Context, params *CreateEventParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateSource

func (c *Client) CreateSource(ctx context.Context, body CreateSourceJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateSourceWithBody

func (c *Client) CreateSourceWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateToken

func (c *Client) CreateToken(ctx context.Context, sourceId SourceId, body CreateTokenJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateTokenWithBody

func (c *Client) CreateTokenWithBody(ctx context.Context, sourceId SourceId, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) DeleteEventType

func (c *Client) DeleteEventType(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) DeleteToken

func (c *Client) DeleteToken(ctx context.Context, sourceId SourceId, tokenId TokenId, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetEventByID

func (c *Client) GetEventByID(ctx context.Context, eventId EventId, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetEventTypeByID

func (c *Client) GetEventTypeByID(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetEventTypes

func (c *Client) GetEventTypes(ctx context.Context, params *GetEventTypesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetEvents

func (c *Client) GetEvents(ctx context.Context, params *GetEventsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetSourceByID

func (c *Client) GetSourceByID(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetSources

func (c *Client) GetSources(ctx context.Context, params *GetSourcesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetTokens

func (c *Client) GetTokens(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetUserProfile

func (c *Client) GetUserProfile(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) LogIn

func (c *Client) LogIn(ctx context.Context, body LogInJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) LogInWithBody

func (c *Client) LogInWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) RollbackEventTypeVersion

func (c *Client) RollbackEventTypeVersion(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

type ClientInterface

type ClientInterface interface {
	// CreateEventWithBody request with any body
	CreateEventWithBody(ctx context.Context, params *CreateEventParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateEvent(ctx context.Context, params *CreateEventParams, body CreateEventJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetEventTypes request
	GetEventTypes(ctx context.Context, params *GetEventTypesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateEventTypeWithBody request with any body
	CreateEventTypeWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateEventType(ctx context.Context, body CreateEventTypeJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// DeleteEventType request
	DeleteEventType(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetEventTypeByID request
	GetEventTypeByID(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

	// RollbackEventTypeVersion request
	RollbackEventTypeVersion(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateEventTypeVersionWithBody request with any body
	CreateEventTypeVersionWithBody(ctx context.Context, eventTypeAction EventTypeAction, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateEventTypeVersion(ctx context.Context, eventTypeAction EventTypeAction, body CreateEventTypeVersionJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetEvents request
	GetEvents(ctx context.Context, params *GetEventsParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetEventByID request
	GetEventByID(ctx context.Context, eventId EventId, reqEditors ...RequestEditorFn) (*http.Response, error)

	// LogInWithBody request with any body
	LogInWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	LogIn(ctx context.Context, body LogInJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetUserProfile request
	GetUserProfile(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetSources request
	GetSources(ctx context.Context, params *GetSourcesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateSourceWithBody request with any body
	CreateSourceWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateSource(ctx context.Context, body CreateSourceJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetSourceByID request
	GetSourceByID(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetTokens request
	GetTokens(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateTokenWithBody request with any body
	CreateTokenWithBody(ctx context.Context, sourceId SourceId, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateToken(ctx context.Context, sourceId SourceId, body CreateTokenJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// DeleteToken request
	DeleteToken(ctx context.Context, sourceId SourceId, tokenId TokenId, reqEditors ...RequestEditorFn) (*http.Response, error)
}

The interface specification for the client above.

type ClientOption

type ClientOption func(*Client) error

ClientOption allows setting custom parameters during construction

func WithBaseURL

func WithBaseURL(baseURL string) ClientOption

WithBaseURL overrides the baseURL.

func WithHTTPClient

func WithHTTPClient(doer HttpRequestDoer) ClientOption

WithHTTPClient allows overriding the default Doer, which is automatically created using http.Client. This is useful for tests.

func WithRequestEditorFn

func WithRequestEditorFn(fn RequestEditorFn) ClientOption

WithRequestEditorFn allows setting up a callback function, which will be called right before sending the request. This can be used to mutate the request.

type ClientWithResponses

type ClientWithResponses struct {
	ClientInterface
}

ClientWithResponses builds on ClientInterface to offer response payloads

func NewClientWithResponses

func NewClientWithResponses(server string, opts ...ClientOption) (*ClientWithResponses, error)

NewClientWithResponses creates a new ClientWithResponses, which wraps Client with return type handling

func (*ClientWithResponses) CreateEventTypeVersionWithBodyWithResponse

func (c *ClientWithResponses) CreateEventTypeVersionWithBodyWithResponse(ctx context.Context, eventTypeAction EventTypeAction, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventTypeVersionResponse, error)

CreateEventTypeVersionWithBodyWithResponse request with arbitrary body returning *CreateEventTypeVersionResponse

func (*ClientWithResponses) CreateEventTypeVersionWithResponse

func (c *ClientWithResponses) CreateEventTypeVersionWithResponse(ctx context.Context, eventTypeAction EventTypeAction, body CreateEventTypeVersionJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventTypeVersionResponse, error)

func (*ClientWithResponses) CreateEventTypeWithBodyWithResponse

func (c *ClientWithResponses) CreateEventTypeWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventTypeResponse, error)

CreateEventTypeWithBodyWithResponse request with arbitrary body returning *CreateEventTypeResponse

func (*ClientWithResponses) CreateEventTypeWithResponse

func (c *ClientWithResponses) CreateEventTypeWithResponse(ctx context.Context, body CreateEventTypeJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventTypeResponse, error)

func (*ClientWithResponses) CreateEventWithBodyWithResponse

func (c *ClientWithResponses) CreateEventWithBodyWithResponse(ctx context.Context, params *CreateEventParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventResponse, error)

CreateEventWithBodyWithResponse request with arbitrary body returning *CreateEventResponse

func (*ClientWithResponses) CreateEventWithResponse

func (c *ClientWithResponses) CreateEventWithResponse(ctx context.Context, params *CreateEventParams, body CreateEventJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventResponse, error)

func (*ClientWithResponses) CreateSourceWithBodyWithResponse

func (c *ClientWithResponses) CreateSourceWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateSourceResponse, error)

CreateSourceWithBodyWithResponse request with arbitrary body returning *CreateSourceResponse

func (*ClientWithResponses) CreateSourceWithResponse

func (c *ClientWithResponses) CreateSourceWithResponse(ctx context.Context, body CreateSourceJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateSourceResponse, error)

func (*ClientWithResponses) CreateTokenWithBodyWithResponse

func (c *ClientWithResponses) CreateTokenWithBodyWithResponse(ctx context.Context, sourceId SourceId, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateTokenResponse, error)

CreateTokenWithBodyWithResponse request with arbitrary body returning *CreateTokenResponse

func (*ClientWithResponses) CreateTokenWithResponse

func (c *ClientWithResponses) CreateTokenWithResponse(ctx context.Context, sourceId SourceId, body CreateTokenJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateTokenResponse, error)

func (*ClientWithResponses) DeleteEventTypeWithResponse

func (c *ClientWithResponses) DeleteEventTypeWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*DeleteEventTypeResponse, error)

DeleteEventTypeWithResponse request returning *DeleteEventTypeResponse

func (*ClientWithResponses) DeleteTokenWithResponse

func (c *ClientWithResponses) DeleteTokenWithResponse(ctx context.Context, sourceId SourceId, tokenId TokenId, reqEditors ...RequestEditorFn) (*DeleteTokenResponse, error)

DeleteTokenWithResponse request returning *DeleteTokenResponse

func (*ClientWithResponses) GetEventByIDWithResponse

func (c *ClientWithResponses) GetEventByIDWithResponse(ctx context.Context, eventId EventId, reqEditors ...RequestEditorFn) (*GetEventByIDResponse, error)

GetEventByIDWithResponse request returning *GetEventByIDResponse

func (*ClientWithResponses) GetEventTypeByIDWithResponse

func (c *ClientWithResponses) GetEventTypeByIDWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*GetEventTypeByIDResponse, error)

GetEventTypeByIDWithResponse request returning *GetEventTypeByIDResponse

func (*ClientWithResponses) GetEventTypesWithResponse

func (c *ClientWithResponses) GetEventTypesWithResponse(ctx context.Context, params *GetEventTypesParams, reqEditors ...RequestEditorFn) (*GetEventTypesResponse, error)

GetEventTypesWithResponse request returning *GetEventTypesResponse

func (*ClientWithResponses) GetEventsWithResponse

func (c *ClientWithResponses) GetEventsWithResponse(ctx context.Context, params *GetEventsParams, reqEditors ...RequestEditorFn) (*GetEventsResponse, error)

GetEventsWithResponse request returning *GetEventsResponse

func (*ClientWithResponses) GetSourceByIDWithResponse

func (c *ClientWithResponses) GetSourceByIDWithResponse(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*GetSourceByIDResponse, error)

GetSourceByIDWithResponse request returning *GetSourceByIDResponse

func (*ClientWithResponses) GetSourcesWithResponse

func (c *ClientWithResponses) GetSourcesWithResponse(ctx context.Context, params *GetSourcesParams, reqEditors ...RequestEditorFn) (*GetSourcesResponse, error)

GetSourcesWithResponse request returning *GetSourcesResponse

func (*ClientWithResponses) GetTokensWithResponse

func (c *ClientWithResponses) GetTokensWithResponse(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*GetTokensResponse, error)

GetTokensWithResponse request returning *GetTokensResponse

func (*ClientWithResponses) GetUserProfileWithResponse

func (c *ClientWithResponses) GetUserProfileWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*GetUserProfileResponse, error)

GetUserProfileWithResponse request returning *GetUserProfileResponse

func (*ClientWithResponses) LogInWithBodyWithResponse

func (c *ClientWithResponses) LogInWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*LogInResponse, error)

LogInWithBodyWithResponse request with arbitrary body returning *LogInResponse

func (*ClientWithResponses) LogInWithResponse

func (c *ClientWithResponses) LogInWithResponse(ctx context.Context, body LogInJSONRequestBody, reqEditors ...RequestEditorFn) (*LogInResponse, error)

func (*ClientWithResponses) RollbackEventTypeVersionWithResponse

func (c *ClientWithResponses) RollbackEventTypeVersionWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*RollbackEventTypeVersionResponse, error)

RollbackEventTypeVersionWithResponse request returning *RollbackEventTypeVersionResponse

type ClientWithResponsesInterface

type ClientWithResponsesInterface interface {
	// CreateEventWithBodyWithResponse request with any body
	CreateEventWithBodyWithResponse(ctx context.Context, params *CreateEventParams, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventResponse, error)

	CreateEventWithResponse(ctx context.Context, params *CreateEventParams, body CreateEventJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventResponse, error)

	// GetEventTypesWithResponse request
	GetEventTypesWithResponse(ctx context.Context, params *GetEventTypesParams, reqEditors ...RequestEditorFn) (*GetEventTypesResponse, error)

	// CreateEventTypeWithBodyWithResponse request with any body
	CreateEventTypeWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventTypeResponse, error)

	CreateEventTypeWithResponse(ctx context.Context, body CreateEventTypeJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventTypeResponse, error)

	// DeleteEventTypeWithResponse request
	DeleteEventTypeWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*DeleteEventTypeResponse, error)

	// GetEventTypeByIDWithResponse request
	GetEventTypeByIDWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*GetEventTypeByIDResponse, error)

	// RollbackEventTypeVersionWithResponse request
	RollbackEventTypeVersionWithResponse(ctx context.Context, eventTypeAction EventTypeAction, reqEditors ...RequestEditorFn) (*RollbackEventTypeVersionResponse, error)

	// CreateEventTypeVersionWithBodyWithResponse request with any body
	CreateEventTypeVersionWithBodyWithResponse(ctx context.Context, eventTypeAction EventTypeAction, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateEventTypeVersionResponse, error)

	CreateEventTypeVersionWithResponse(ctx context.Context, eventTypeAction EventTypeAction, body CreateEventTypeVersionJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateEventTypeVersionResponse, error)

	// GetEventsWithResponse request
	GetEventsWithResponse(ctx context.Context, params *GetEventsParams, reqEditors ...RequestEditorFn) (*GetEventsResponse, error)

	// GetEventByIDWithResponse request
	GetEventByIDWithResponse(ctx context.Context, eventId EventId, reqEditors ...RequestEditorFn) (*GetEventByIDResponse, error)

	// LogInWithBodyWithResponse request with any body
	LogInWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*LogInResponse, error)

	LogInWithResponse(ctx context.Context, body LogInJSONRequestBody, reqEditors ...RequestEditorFn) (*LogInResponse, error)

	// GetUserProfileWithResponse request
	GetUserProfileWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*GetUserProfileResponse, error)

	// GetSourcesWithResponse request
	GetSourcesWithResponse(ctx context.Context, params *GetSourcesParams, reqEditors ...RequestEditorFn) (*GetSourcesResponse, error)

	// CreateSourceWithBodyWithResponse request with any body
	CreateSourceWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateSourceResponse, error)

	CreateSourceWithResponse(ctx context.Context, body CreateSourceJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateSourceResponse, error)

	// GetSourceByIDWithResponse request
	GetSourceByIDWithResponse(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*GetSourceByIDResponse, error)

	// GetTokensWithResponse request
	GetTokensWithResponse(ctx context.Context, sourceId SourceId, reqEditors ...RequestEditorFn) (*GetTokensResponse, error)

	// CreateTokenWithBodyWithResponse request with any body
	CreateTokenWithBodyWithResponse(ctx context.Context, sourceId SourceId, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateTokenResponse, error)

	CreateTokenWithResponse(ctx context.Context, sourceId SourceId, body CreateTokenJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateTokenResponse, error)

	// DeleteTokenWithResponse request
	DeleteTokenWithResponse(ctx context.Context, sourceId SourceId, tokenId TokenId, reqEditors ...RequestEditorFn) (*DeleteTokenResponse, error)
}

ClientWithResponsesInterface is the interface specification for the client with responses above.

type Context

type Context struct {
	Location  string  `json:"location"`
	UserAgent *string `json:"user_agent,omitempty"`
}

Context defines model for Context.

type CreateEventJSONBody

type CreateEventJSONBody struct {
	// Action Event type action
	Action string `json:"action"`
	Actor  struct {
		Id       string                  `json:"id"`
		Metadata *map[string]interface{} `json:"metadata,omitempty"`
		Name     *string                 `json:"name,omitempty"`
		Type     string                  `json:"type"`
	} `json:"actor"`
	Context struct {
		Location  string  `json:"location"`
		UserAgent *string `json:"user_agent,omitempty"`
	} `json:"context"`
	Metadata   *map[string]interface{} `json:"metadata,omitempty"`
	OccurredAt time.Time               `json:"occurred_at"`
	SourceId   string                  `json:"source_id"`
	Targets    []struct {
		Id       string                  `json:"id"`
		Metadata *map[string]interface{} `json:"metadata,omitempty"`
		Name     *string                 `json:"name,omitempty"`
		Type     string                  `json:"type"`
	} `json:"targets"`
	Version int `json:"version"`
}

CreateEventJSONBody defines parameters for CreateEvent.

type CreateEventJSONRequestBody

type CreateEventJSONRequestBody CreateEventJSONBody

CreateEventJSONRequestBody defines body for CreateEvent for application/json ContentType.

type CreateEventParams

type CreateEventParams struct {
	XToken XToken `json:"x-token"`
}

CreateEventParams defines parameters for CreateEvent.

type CreateEventResponse

type CreateEventResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSONDefault  *InternalServerError
}

func ParseCreateEventResponse

func ParseCreateEventResponse(rsp *http.Response) (*CreateEventResponse, error)

ParseCreateEventResponse parses an HTTP response from a CreateEventWithResponse call

func (CreateEventResponse) Status

func (r CreateEventResponse) Status() string

Status returns HTTPResponse.Status

func (CreateEventResponse) StatusCode

func (r CreateEventResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type CreateEventTypeJSONBody

type CreateEventTypeJSONBody struct {
	Action                       string   `json:"action"`
	Schema                       *string  `json:"schema,omitempty"`
	ShouldValidateMetadataSchema bool     `json:"should_validate_metadata_schema"`
	TargetTypes                  []string `json:"target_types"`
}

CreateEventTypeJSONBody defines parameters for CreateEventType.

type CreateEventTypeJSONRequestBody

type CreateEventTypeJSONRequestBody CreateEventTypeJSONBody

CreateEventTypeJSONRequestBody defines body for CreateEventType for application/json ContentType.

type CreateEventTypeResponse

type CreateEventTypeResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON201      *EventType
	JSON400      *BadRequestError
	JSONDefault  *InternalServerError
}

func ParseCreateEventTypeResponse

func ParseCreateEventTypeResponse(rsp *http.Response) (*CreateEventTypeResponse, error)

ParseCreateEventTypeResponse parses an HTTP response from a CreateEventTypeWithResponse call

func (CreateEventTypeResponse) Status

func (r CreateEventTypeResponse) Status() string

Status returns HTTPResponse.Status

func (CreateEventTypeResponse) StatusCode

func (r CreateEventTypeResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type CreateEventTypeVersionJSONBody

type CreateEventTypeVersionJSONBody struct {
	Schema      *string  `json:"schema,omitempty"`
	TargetTypes []string `json:"target_types"`
}

CreateEventTypeVersionJSONBody defines parameters for CreateEventTypeVersion.

type CreateEventTypeVersionJSONRequestBody

type CreateEventTypeVersionJSONRequestBody CreateEventTypeVersionJSONBody

CreateEventTypeVersionJSONRequestBody defines body for CreateEventTypeVersion for application/json ContentType.

type CreateEventTypeVersionResponse

type CreateEventTypeVersionResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON400      *BadRequestError
	JSON404      *NotFoundError
	JSONDefault  *InternalServerError
}

func ParseCreateEventTypeVersionResponse

func ParseCreateEventTypeVersionResponse(rsp *http.Response) (*CreateEventTypeVersionResponse, error)

ParseCreateEventTypeVersionResponse parses an HTTP response from a CreateEventTypeVersionWithResponse call

func (CreateEventTypeVersionResponse) Status

Status returns HTTPResponse.Status

func (CreateEventTypeVersionResponse) StatusCode

func (r CreateEventTypeVersionResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type CreateSourceJSONBody

type CreateSourceJSONBody struct {
	Name string `json:"name"`
}

CreateSourceJSONBody defines parameters for CreateSource.

type CreateSourceJSONRequestBody

type CreateSourceJSONRequestBody CreateSourceJSONBody

CreateSourceJSONRequestBody defines body for CreateSource for application/json ContentType.

type CreateSourceResponse

type CreateSourceResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON204      *Source
	JSONDefault  *InternalServerError
}

func ParseCreateSourceResponse

func ParseCreateSourceResponse(rsp *http.Response) (*CreateSourceResponse, error)

ParseCreateSourceResponse parses an HTTP response from a CreateSourceWithResponse call

func (CreateSourceResponse) Status

func (r CreateSourceResponse) Status() string

Status returns HTTPResponse.Status

func (CreateSourceResponse) StatusCode

func (r CreateSourceResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type CreateTokenJSONBody

type CreateTokenJSONBody struct {
	Name string `json:"name"`
}

CreateTokenJSONBody defines parameters for CreateToken.

type CreateTokenJSONRequestBody

type CreateTokenJSONRequestBody CreateTokenJSONBody

CreateTokenJSONRequestBody defines body for CreateToken for application/json ContentType.

type CreateTokenResponse

type CreateTokenResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON201      *Token
	JSONDefault  *InternalServerError
}

func ParseCreateTokenResponse

func ParseCreateTokenResponse(rsp *http.Response) (*CreateTokenResponse, error)

ParseCreateTokenResponse parses an HTTP response from a CreateTokenWithResponse call

func (CreateTokenResponse) Status

func (r CreateTokenResponse) Status() string

Status returns HTTPResponse.Status

func (CreateTokenResponse) StatusCode

func (r CreateTokenResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type DeleteEventTypeResponse

type DeleteEventTypeResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON400      *BadRequestError
	JSONDefault  *InternalServerError
}

func ParseDeleteEventTypeResponse

func ParseDeleteEventTypeResponse(rsp *http.Response) (*DeleteEventTypeResponse, error)

ParseDeleteEventTypeResponse parses an HTTP response from a DeleteEventTypeWithResponse call

func (DeleteEventTypeResponse) Status

func (r DeleteEventTypeResponse) Status() string

Status returns HTTPResponse.Status

func (DeleteEventTypeResponse) StatusCode

func (r DeleteEventTypeResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type DeleteTokenResponse

type DeleteTokenResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSONDefault  *InternalServerError
}

func ParseDeleteTokenResponse

func ParseDeleteTokenResponse(rsp *http.Response) (*DeleteTokenResponse, error)

ParseDeleteTokenResponse parses an HTTP response from a DeleteTokenWithResponse call

func (DeleteTokenResponse) Status

func (r DeleteTokenResponse) Status() string

Status returns HTTPResponse.Status

func (DeleteTokenResponse) StatusCode

func (r DeleteTokenResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ErrorSchema

type ErrorSchema struct {
	// Error Error custom error code such as 'email_in_use'
	Error string `json:"error"`

	// Message A description about the error
	Message string `json:"message"`
}

ErrorSchema defines model for ErrorSchema.

type Event

type Event struct {
	Id         string                  `json:"id"`
	SourceId   string                  `json:"source_id"`
	Action     string                  `json:"action"`
	Version    int                     `json:"version"`
	Targets    []Target                `json:"targets"`
	Metadata   *map[string]interface{} `json:"metadata,omitempty"`
	OccurredAt string                  `json:"occurred_at"`
	Actor      Actor                   `json:"actor"`
	Context    Context                 `json:"context"`
}

Event defines model for Event.

type EventId

type EventId = string

EventId defines model for event_id.

type EventList

type EventList struct {
	Data           []Event `json:"data"`
	LastItemCursor string  `json:"last_item_cursor"`
}

EventList defines model for EventList.

type EventType

type EventType struct {
	Action                       string             `json:"action"`
	Versions                     []EventTypeVersion `json:"versions"`
	ShouldValidateMetadataSchema bool               `json:"should_validate_metadata_schema"`
	CreatedAt                    time.Time          `json:"created_at"`
}

EventType defines model for EventType.

type EventTypeAction

type EventTypeAction = string

EventTypeAction defines model for event_type_action.

type EventTypeList

type EventTypeList struct {
	Data       []EventType `json:"data"`
	Pagination Pagination  `json:"pagination"`
}

EventTypeList defines model for EventTypeList.

type EventTypeVersion

type EventTypeVersion struct {
	Version     int       `json:"version"`
	TargetTypes []string  `json:"target_types"`
	Schema      *string   `json:"schema,omitempty"`
	CreatedAt   time.Time `json:"created_at"`
}

EventTypeVersion defines model for EventTypeVersion.

type EventsByActorId

type EventsByActorId = string

EventsByActorId defines model for events_by_actor_id.

type EventsByActorName

type EventsByActorName = string

EventsByActorName defines model for events_by_actor_name.

type EventsByTargetId

type EventsByTargetId = string

EventsByTargetId defines model for events_by_target_id.

type EventsEndDate

type EventsEndDate = time.Time

EventsEndDate defines model for events_end_date.

type EventsStartDate

type EventsStartDate = time.Time

EventsStartDate defines model for events_start_date.

type GetEventByIDResponse

type GetEventByIDResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *Event
	JSON404      *NotFoundError
	JSONDefault  *InternalServerError
}

func ParseGetEventByIDResponse

func ParseGetEventByIDResponse(rsp *http.Response) (*GetEventByIDResponse, error)

ParseGetEventByIDResponse parses an HTTP response from a GetEventByIDWithResponse call

func (GetEventByIDResponse) Status

func (r GetEventByIDResponse) Status() string

Status returns HTTPResponse.Status

func (GetEventByIDResponse) StatusCode

func (r GetEventByIDResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetEventTypeByIDResponse

type GetEventTypeByIDResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *EventType
	JSON400      *BadRequestError
	JSON404      *NotFoundError
	JSONDefault  *InternalServerError
}

func ParseGetEventTypeByIDResponse

func ParseGetEventTypeByIDResponse(rsp *http.Response) (*GetEventTypeByIDResponse, error)

ParseGetEventTypeByIDResponse parses an HTTP response from a GetEventTypeByIDWithResponse call

func (GetEventTypeByIDResponse) Status

func (r GetEventTypeByIDResponse) Status() string

Status returns HTTPResponse.Status

func (GetEventTypeByIDResponse) StatusCode

func (r GetEventTypeByIDResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetEventTypesParams

type GetEventTypesParams struct {
	// Limit The number of items per page
	Limit *PaginationLimit `form:"limit,omitempty" json:"limit,omitempty"`

	// Page The page number
	Page *PaginationPage `form:"page,omitempty" json:"page,omitempty"`

	// Action Action filter
	Action *ActionFilter `form:"action,omitempty" json:"action,omitempty"`
}

GetEventTypesParams defines parameters for GetEventTypes.

type GetEventTypesResponse

type GetEventTypesResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON201      *EventTypeList
	JSON400      *BadRequestError
	JSONDefault  *InternalServerError
}

func ParseGetEventTypesResponse

func ParseGetEventTypesResponse(rsp *http.Response) (*GetEventTypesResponse, error)

ParseGetEventTypesResponse parses an HTTP response from a GetEventTypesWithResponse call

func (GetEventTypesResponse) Status

func (r GetEventTypesResponse) Status() string

Status returns HTTPResponse.Status

func (GetEventTypesResponse) StatusCode

func (r GetEventTypesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetEventsParams

type GetEventsParams struct {
	SourceId SourceIdQuery `form:"source_id" json:"source_id"`

	// StartFrom Opaque cursor returned by the previous page. Omit to start from the most recent event.
	StartFrom *StartFromCursor `form:"start_from,omitempty" json:"start_from,omitempty"`

	// Limit The number of items per page
	Limit     *PaginationLimit   `form:"limit,omitempty" json:"limit,omitempty"`
	ActorId   *EventsByActorId   `form:"actor_id,omitempty" json:"actor_id,omitempty"`
	ActorName *EventsByActorName `form:"actor_name,omitempty" json:"actor_name,omitempty"`
	TargetId  *EventsByTargetId  `form:"target_id,omitempty" json:"target_id,omitempty"`
	StartDate *EventsStartDate   `form:"start_date,omitempty" json:"start_date,omitempty"`
	EndDate   *EventsEndDate     `form:"end_date,omitempty" json:"end_date,omitempty"`
}

GetEventsParams defines parameters for GetEvents.

type GetEventsResponse

type GetEventsResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *EventList
	JSONDefault  *InternalServerError
}

func ParseGetEventsResponse

func ParseGetEventsResponse(rsp *http.Response) (*GetEventsResponse, error)

ParseGetEventsResponse parses an HTTP response from a GetEventsWithResponse call

func (GetEventsResponse) Status

func (r GetEventsResponse) Status() string

Status returns HTTPResponse.Status

func (GetEventsResponse) StatusCode

func (r GetEventsResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetSourceByIDResponse

type GetSourceByIDResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *Source
	JSON404      *NotFoundError
	JSONDefault  *InternalServerError
}

func ParseGetSourceByIDResponse

func ParseGetSourceByIDResponse(rsp *http.Response) (*GetSourceByIDResponse, error)

ParseGetSourceByIDResponse parses an HTTP response from a GetSourceByIDWithResponse call

func (GetSourceByIDResponse) Status

func (r GetSourceByIDResponse) Status() string

Status returns HTTPResponse.Status

func (GetSourceByIDResponse) StatusCode

func (r GetSourceByIDResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetSourcesParams

type GetSourcesParams struct {
	// Limit The number of items per page
	Limit *PaginationLimit `form:"limit,omitempty" json:"limit,omitempty"`

	// Page The page number
	Page *PaginationPage `form:"page,omitempty" json:"page,omitempty"`

	// Name Name filter
	Name *NameFilter `form:"name,omitempty" json:"name,omitempty"`
}

GetSourcesParams defines parameters for GetSources.

type GetSourcesResponse

type GetSourcesResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *SourceList
	JSONDefault  *InternalServerError
}

func ParseGetSourcesResponse

func ParseGetSourcesResponse(rsp *http.Response) (*GetSourcesResponse, error)

ParseGetSourcesResponse parses an HTTP response from a GetSourcesWithResponse call

func (GetSourcesResponse) Status

func (r GetSourcesResponse) Status() string

Status returns HTTPResponse.Status

func (GetSourcesResponse) StatusCode

func (r GetSourcesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetTokensResponse

type GetTokensResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *TokenList
	JSONDefault  *InternalServerError
}

func ParseGetTokensResponse

func ParseGetTokensResponse(rsp *http.Response) (*GetTokensResponse, error)

ParseGetTokensResponse parses an HTTP response from a GetTokensWithResponse call

func (GetTokensResponse) Status

func (r GetTokensResponse) Status() string

Status returns HTTPResponse.Status

func (GetTokensResponse) StatusCode

func (r GetTokensResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetUserProfileResponse

type GetUserProfileResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *User
	JSONDefault  *InternalServerError
}

func ParseGetUserProfileResponse

func ParseGetUserProfileResponse(rsp *http.Response) (*GetUserProfileResponse, error)

ParseGetUserProfileResponse parses an HTTP response from a GetUserProfileWithResponse call

func (GetUserProfileResponse) Status

func (r GetUserProfileResponse) Status() string

Status returns HTTPResponse.Status

func (GetUserProfileResponse) StatusCode

func (r GetUserProfileResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type HttpRequestDoer

type HttpRequestDoer interface {
	Do(req *http.Request) (*http.Response, error)
}

Doer performs HTTP requests.

The standard http.Client implements this interface.

type InternalServerError

type InternalServerError = ErrorSchema

InternalServerError defines model for InternalServerError.

type LogIn

type LogIn struct {
	Jwt string `json:"jwt"`
}

LogIn defines model for LogIn.

type LogInJSONBody

type LogInJSONBody struct {
	Email    string `json:"email"`
	Password string `json:"password"`
}

LogInJSONBody defines parameters for LogIn.

type LogInJSONRequestBody

type LogInJSONRequestBody LogInJSONBody

LogInJSONRequestBody defines body for LogIn for application/json ContentType.

type LogInResponse

type LogInResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON200      *LogIn
	JSON401      *UnauthorizedError
	JSONDefault  *InternalServerError
}

func ParseLogInResponse

func ParseLogInResponse(rsp *http.Response) (*LogInResponse, error)

ParseLogInResponse parses an HTTP response from a LogInWithResponse call

func (LogInResponse) Status

func (r LogInResponse) Status() string

Status returns HTTPResponse.Status

func (LogInResponse) StatusCode

func (r LogInResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type NameFilter

type NameFilter = string

NameFilter defines model for name_filter.

type NotFoundError

type NotFoundError = ErrorSchema

NotFoundError defines model for NotFoundError.

type Pagination

type Pagination struct {
	Total       int `json:"total"`
	PerPage     int `json:"per_page"`
	CurrentPage int `json:"current_page"`
	TotalPages  int `json:"total_pages"`
}

Pagination defines model for Pagination.

type PaginationLimit

type PaginationLimit = int

PaginationLimit defines model for pagination_limit.

type PaginationPage

type PaginationPage = int

PaginationPage defines model for pagination_page.

type RequestEditorFn

type RequestEditorFn func(ctx context.Context, req *http.Request) error

RequestEditorFn is the function signature for the RequestEditor callback function

type RollbackEventTypeVersionResponse

type RollbackEventTypeVersionResponse struct {
	Body         []byte
	HTTPResponse *http.Response
	JSON400      *BadRequestError
	JSONDefault  *InternalServerError
}

func ParseRollbackEventTypeVersionResponse

func ParseRollbackEventTypeVersionResponse(rsp *http.Response) (*RollbackEventTypeVersionResponse, error)

ParseRollbackEventTypeVersionResponse parses an HTTP response from a RollbackEventTypeVersionWithResponse call

func (RollbackEventTypeVersionResponse) Status

Status returns HTTPResponse.Status

func (RollbackEventTypeVersionResponse) StatusCode

func (r RollbackEventTypeVersionResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type Source

type Source struct {
	Id        string    `json:"id"`
	Name      string    `json:"name"`
	CreatedAt time.Time `json:"created_at"`
	UpdatedAt time.Time `json:"updated_at"`
}

Source defines model for Source.

type SourceId

type SourceId = string

SourceId defines model for source_id.

type SourceIdQuery

type SourceIdQuery = string

SourceIdQuery defines model for source_id_query.

type SourceList

type SourceList struct {
	Data       []Source   `json:"data"`
	Pagination Pagination `json:"pagination"`
}

SourceList defines model for SourceList.

type StartFromCursor

type StartFromCursor = string

StartFromCursor defines model for start_from_cursor.

type Target

type Target struct {
	Id         string                  `json:"id"`
	Metadata   *map[string]interface{} `json:"metadata,omitempty"`
	Name       *string                 `json:"name,omitempty"`
	TargetType string                  `json:"target_type"`
}

Target defines model for Target.

type Token

type Token struct {
	Id        string    `json:"id"`
	Value     string    `json:"value"`
	Name      string    `json:"name"`
	SourceId  string    `json:"source_id"`
	CreatedAt time.Time `json:"created_at"`
}

Token defines model for Token.

type TokenId

type TokenId = string

TokenId defines model for token_id.

type TokenList

type TokenList struct {
	Data []Token `json:"data"`
}

TokenList defines model for TokenList.

type UnauthorizedError

type UnauthorizedError = ErrorSchema

UnauthorizedError defines model for UnauthorizedError.

type User

type User struct {
	Id    string `json:"id"`
	Email string `json:"email"`
	Role  string `json:"role"`
}

User defines model for User.

type XToken

type XToken = string

XToken defines model for x_token.

Jump to